Getting started
===============

Installation
------------

Required dependencies:

* Python 3.9 or later

Install from PyPI in your virtual environment:

.. code:: shell

    python -m pip install axsdb
